@@ -108,6 +108,12 @@ class CLIParser:
             required=False,
             help="print a stack trace (etc.) on error",
         )
+        parser.add_argument(
+            "--pac",
+            action="store_true",
+            required=False,
+            help="enable PAC (proxy auto-configuration) support",
+        )
 
         # Module-specific argument sets
 
@@ -143,14 +149,6 @@ class CLIParser:
                 help="the executable to use",
                 metavar="<executable>",
             )
-            parser.add_argument(
-                "--task-batch-size",
-                "-b",
-                type=int,
-                required=False,
-                help="the batch size for task submission",
-                metavar="<batch_size>",
-            )
             parser.add_argument(
                 "--task-type",
                 "-T",
@@ -167,6 +165,21 @@ class CLIParser:
                 help="the number of times to submit the task",
                 metavar="<task_count>",
             )
+            parser.add_argument(
+                "--task-batch-size",
+                "-b",
+                type=int,
+                required=False,
+                help="the batch size for task submission",
+                metavar="<batch_size>",
+            )
+            parser.add_argument(
+                "--pause-between-batches",
+                "-P",
+                action="store_true",
+                required=False,
+                help="pause for user input between batches (for debugging)",
+            )
             parser.add_argument(
                 "--csv-file",
                 "-V",
@@ -219,7 +232,6 @@ class CLIParser:
                 "cancel",
                 "delete",
                 "download",
-                "list",
                 "shutdown",
                 "terminate",
             ]
@@ -252,6 +264,14 @@ class CLIParser:
                 required=False,
                 help="download without requiring user confirmation",
             )
+            parser.add_argument(
+                "--directory",
+                "-d",
+                type=str,
+                required=False,
+                help="the directory to use for downloaded objects",
+                metavar="<directory>",
+            )
 
         if "list" in sys.argv[0]:
             parser.add_argument(
@@ -261,6 +281,13 @@ class CLIParser:
                 required=False,
                 help="list YellowDog Object Store object paths",
             )
+            parser.add_argument(
+                "--tree",
+                "-T",
+                action="store_true",
+                required=False,
+                help="when used with '--object-paths', list the full object tree",
+            )
             parser.add_argument(
                 "--work-requirements",
                 "-w",
@@ -509,10 +536,18 @@ class CLIParser:
     def live_only(self) -> Optional[bool]:
         return self.args.live_only
 
+    @property
+    def object_tree(self) -> Optional[bool]:
+        return self.args.tree
+
     @property
     def debug(self) -> Optional[bool]:
         return self.args.debug
 
+    @property
+    def use_pac(self) -> Optional[bool]:
+        return self.args.pac
+
     @property
     def directory(self) -> str:
         return "" if self.args.directory is None else self.args.directory
@@ -573,6 +608,10 @@ class CLIParser:
     def jsonnet_dry_run(self) -> Optional[bool]:
         return self.args.jsonnet_dry_run
 
+    @property
+    def pause_between_batches(self) -> Optional[bool]:
+        return self.args.pause_between_batches
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
