@@ -4,7 +4,9 @@
 A script to upload files to the YellowDog Object Store.
 """
 
+from glob import glob
 from os import chdir
+from os import name as os_name
 from os import walk as os_walk
 from os.path import join as os_path_join
 from pathlib import Path
@@ -20,8 +22,7 @@ def main():
     if ARGS_PARSER.content_path is not None and ARGS_PARSER.content_path != "":
         chdir(ARGS_PARSER.content_path)
         print_log(
-            "Uploading files relative to local directory: "
-            f"'{ARGS_PARSER.content_path}'"
+            f"Uploading files relative to local directory: '{ARGS_PARSER.content_path}'"
         )
 
     print_log(
@@ -30,6 +31,14 @@ def main():
     )
 
     files_set = set(ARGS_PARSER.files)
+    if os_name == "nt":
+        # Windows wildcard expansion (not done natively by the Windows shell)
+        files_set = {f for files in files_set for f in glob(files)}
+
+    if len(files_set) == 0:
+        print_log("No files to upload")
+        return
+
     added_files_set = set()
     removed_dirs_set = set()
 
@@ -52,16 +61,22 @@ def main():
 
     if ARGS_PARSER.flatten:
         print_log("Flattening upload paths")
+
+    uploaded_file_count = 0
     for file in files_set:
-        upload_file(
-            client=CLIENT,
-            filename=file,
-            id=ARGS_PARSER.directory,
-            namespace=CONFIG_COMMON.namespace,
-            url=CONFIG_COMMON.url,
-            flatten_upload_paths=ARGS_PARSER.flatten,
-        )
-    print_log(f"Uploaded {len(files_set)} files")
+        if (
+            upload_file(
+                client=CLIENT,
+                filename=file,
+                id=ARGS_PARSER.directory,
+                namespace=CONFIG_COMMON.namespace,
+                url=CONFIG_COMMON.url,
+                flatten_upload_paths=ARGS_PARSER.flatten,
+            )
+            is True
+        ):
+            uploaded_file_count += 1
+    print_log(f"Uploaded {uploaded_file_count} files")
 
 
 # Standalone entry point
